udb_plugin_samples

package module
v0.5.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 18, 2026 License: MPL-2.0 Imports: 4 Imported by: 0

README

udb-plugin-samples

Sample plugin for the UDB project which contains simple boards and datasources for demo and example purposes.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type UdbSamplePlugin

type UdbSamplePlugin struct{}

func (*UdbSamplePlugin) Configure

func (p *UdbSamplePlugin) Configure(config types.PluginConfig) error

func (*UdbSamplePlugin) GetBoardMap

func (p *UdbSamplePlugin) GetBoardMap() map[string]types.BoardFactory

func (*UdbSamplePlugin) GetDatasourceMap

func (p *UdbSamplePlugin) GetDatasourceMap() map[string]types.DatasourceFactory

func (*UdbSamplePlugin) GetId

func (p *UdbSamplePlugin) GetId() string

func (*UdbSamplePlugin) GetName

func (p *UdbSamplePlugin) GetName() string

Directories

Path Synopsis
cmd
gen-assets command
gen-assets generates the sample image files embedded by the boards package.
gen-assets generates the sample image files embedded by the boards package.

Jump to