Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type UdbSamplePlugin ¶
type UdbSamplePlugin struct{}
func (*UdbSamplePlugin) Configure ¶
func (p *UdbSamplePlugin) Configure(config types.PluginConfig) error
func (*UdbSamplePlugin) GetBoardMap ¶
func (p *UdbSamplePlugin) GetBoardMap() map[string]types.Board
func (*UdbSamplePlugin) GetDatasourceMap ¶
func (p *UdbSamplePlugin) GetDatasourceMap() map[string]types.Datasource
func (*UdbSamplePlugin) GetId ¶
func (p *UdbSamplePlugin) GetId() string
func (*UdbSamplePlugin) GetName ¶
func (p *UdbSamplePlugin) GetName() string
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
|
|
|
gen-assets
command
gen-assets generates the sample image files embedded by the boards package.
|
gen-assets generates the sample image files embedded by the boards package. |
Click to show internal directories.
Click to hide internal directories.