Documentation
¶
Index ¶
- type UdbSamplePlugin
- func (p *UdbSamplePlugin) Configure(config types.PluginConfig) error
- func (p *UdbSamplePlugin) GetAllBoards() []types.Board[any]
- func (p *UdbSamplePlugin) GetAllDatasources() []types.Datasource[any]
- func (p *UdbSamplePlugin) GetBoardMap() map[string]types.Board[any]
- func (p *UdbSamplePlugin) GetDatasourceMap() map[string]types.Datasource[any]
- func (p *UdbSamplePlugin) GetId() string
- func (p *UdbSamplePlugin) GetName() string
- func (p *UdbSamplePlugin) GetPluginType() types.PluginType
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type UdbSamplePlugin ¶
type UdbSamplePlugin struct{}
func (*UdbSamplePlugin) Configure ¶
func (p *UdbSamplePlugin) Configure(config types.PluginConfig) error
func (*UdbSamplePlugin) GetAllBoards ¶
func (p *UdbSamplePlugin) GetAllBoards() []types.Board[any]
func (*UdbSamplePlugin) GetAllDatasources ¶
func (p *UdbSamplePlugin) GetAllDatasources() []types.Datasource[any]
func (*UdbSamplePlugin) GetBoardMap ¶
func (p *UdbSamplePlugin) GetBoardMap() map[string]types.Board[any]
func (*UdbSamplePlugin) GetDatasourceMap ¶
func (p *UdbSamplePlugin) GetDatasourceMap() map[string]types.Datasource[any]
func (*UdbSamplePlugin) GetId ¶
func (p *UdbSamplePlugin) GetId() string
func (*UdbSamplePlugin) GetName ¶
func (p *UdbSamplePlugin) GetName() string
func (*UdbSamplePlugin) GetPluginType ¶
func (p *UdbSamplePlugin) GetPluginType() types.PluginType
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
|
|
|
gen-assets
command
gen-assets generates the sample image files embedded by the boards package.
|
gen-assets generates the sample image files embedded by the boards package. |
Click to show internal directories.
Click to hide internal directories.